==> nextcloud-app-bookmarks-1:13.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/pt_PT.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "Details" : "Detalhes",
    "Rename" : "Renomear",
    "Copy link" : "Copiar hiperligação",
    "Move" : "Mover",
    "Delete" : "Apagar",
    "Link copied to clipboard" : "Ligação copiada para a área de transferência",
    "Select all" : "Seleccionar todos",
    "Go back" : "Voltar",
    "Share folder" : "Partilhar pasta",
    "New" : "Novo",
    "New folder" : "Nova pasta",
    "Search" : "Pesquisa sobre",
    "Add a bookmark" : "Adicionar um marcador",
    "Rename folder" : "Renomear pasta",
    "Delete folder" : "Apagar pasta",
    "Choose folder" : "Escolher pasta",
    "Submit" : "Submeter",
    "Cancel" : "Cancelar",
    "All bookmarks" : "Todos os marcadores",
    "Recent" : "Recentes",
    "Shared with you" : "Partilhado consigo",
    "Files" : "Ficheiros",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Title" : "Título",
    "Link" : "Link",
    "Root folder" : "Pasta raiz",
    "Tags" : "Marcações",
    "Notes" : "Notas",
    "Download file" : "Transferir ficheiro",
    "Owner" : "Proprietário",
    "Sharing" : "Partilha",
    "Select a user or group" : "Selecionar utilizador ou grupo",
    "Share link" : "Share link",
    "Allow editing" : "Permitir edição",
    "Allow resharing" : "Permitir repartilha",
    "Link copied" : "Link copiado",
    "Privacy" : "Privacidade",
    "Failed to save settings" : "Erro ao gravar as definições",
    "Folder" : "Pasta",
    "Save" : "Guardar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-bookmarks-1:16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/pt_PT.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "Link copied to clipboard" : "Ligação copiada para a área de transferência",
    "Details" : "Detalhes",
    "Rename" : "Renomear",
    "Copy link" : "Copiar hiperligação",
    "Move" : "Mover",
    "This content is being downloaded for offline use. Please check back later." : "Este conteúdo está a ser transferido para utilização ''off-line''. Por favor, volte mais tarde.",
    "Select all" : "Selecionar tudo",
    "Go back" : "Voltar",
    "Share folder" : "Partilhar pasta",
    "New" : "Novo",
    "New folder" : "Nova pasta",
    "Search" : "Pesquisa sobre",
    "Empty trash bin" : "Esvaziar a reciclagem",
    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas","%n pastas"],
    "Add a bookmark" : "Adicionar um marcador",
    "Shared by {user}" : "Shared by {user}",
    "Rename folder" : "Renomear pasta",
    "Choose folder" : "Escolher pasta",
    "Submit" : "Submeter",
    "Cancel" : "Cancelar",
    "All bookmarks" : "Todos os marcadores",
    "Recent" : "Recentes",
    "Shared with you" : "Partilhado consigo",
    "Files" : "Ficheiros",
    "Delete" : "Apagar",
    "Need help?" : "Precisa de ajuda?",
    "Created on {date}" : "Criado em {date}",
    "Title" : "Título",
    "Link" : "Link",
    "Root folder" : "Pasta raiz",
    "Tags" : "Marcações",
    "Notes" : "Notas",
    "Download file" : "Transferir ficheiro",
    "Link copied" : "Link copiado",
    "Owner" : "Proprietário",
    "Sharing" : "Partilha",
    "Select a user or group" : "Selecionar utilizador ou grupo",
    "Share link" : "Share link",
    "Allow editing" : "Permitir edição",
    "Allow resharing" : "Permitir repartilha",
    "Failed to save settings" : "Erro ao gravar as definições",
    "Privacy" : "Privacidade",
    "Performance" : "Performance",
    "Folder" : "Pasta",
    "Save" : "Guardar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
